@@ -1,12 +1,26 @@
 
 
-
 #
 # Copy of ginv from package "MASS"
 # Only difference: Possibility to return singular values
 #
+#  + override input by ginv_tol_FromUser
+#
 my_ginv = function (X, tol = sqrt(.Machine$double.eps),singularReturn=FALSE)
 {
+  
+    tolFromUser <- get0("ginv_tol_FromUser", ifnotfound = FALSE)
+    if(tolFromUser){
+      if(is.logical(tolFromUser))
+        tol = sqrt(.Machine$double.eps)
+      else{
+        if(is.numeric(tolFromUser))
+          tol = tolFromUser
+      }
+      #cat("ginv-tol set to",tol,"\n")
+      #flush.console()
+    }
+  
     if (length(dim(X)) > 2L || !(is.numeric(X) || is.complex(X)))
         stop("'X' must be a numeric or complex matrix")
     if (!is.matrix(X))
